==> org.eclipse.objectteams.otdt.jdt.ui.source_2.1.0.201203201248.jar: org/eclipse/objectteams/otdt/internal/ui/Messages.java <==
/**********************************************************************
 * This file is part of "Object Teams Development Tooling"-Software
 * 
 * Copyright 2007 Technical University Berlin, Germany.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: Messages.java 23438 2010-02-04 20:05:24Z stephan $
 * 
 * Please visit http://www.eclipse.org/objectteams for updates and contact.
 * 
 * Contributors:
 * Technical University Berlin - Initial API and implementation
 **********************************************************************/
package org.eclipse.objectteams.otdt.internal.ui;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = Messages.class.getName();

	public static String Completion_method_binding_label;
	public static String Completion_callout_label;
	public static String Completion_callin_label;

	public static String Completion_callout_to_field_label;

	public static String Completion_default_lifting_constructor_label;

	public static String Completion_override_role_label;

	public static String OTLayoutActionGroup_MenuOTPresentations;
	public static String OTLayoutActionGroup_MenuShowCallinLabels;
	public static String OTLayoutActionGroup_MenuDontShowCallinLabels;

	public static String PackageExplorer_DisplayRoleFilesAction;
	public static String PackageExplorer_DisplayRoleFilesDescription;
	public static String PackageExplorer_DisplayRoleFilesTooltip;

	public static String QuickOutline__and_role_files;

	public static String ViewAdaptor_guard_predicate_postfix;
	
	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() { /* do not instantiate */ }
}

==> org.eclipse.objectteams.otdt.jdt.ui.source_2.5.0.201606070956.jar: org/eclipse/objectteams/otdt/internal/ui/Messages.java <==
/**********************************************************************
 * This file is part of "Object Teams Development Tooling"-Software
 * 
 * Copyright 2007 Technical University Berlin, Germany.
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * $Id: Messages.java 23438 2010-02-04 20:05:24Z stephan $
 * 
 * Please visit http://www.eclipse.org/objectteams for updates and contact.
 * 
 * Contributors:
 * Technical University Berlin - Initial API and implementation
 **********************************************************************/
package org.eclipse.objectteams.otdt.internal.ui;

import org.eclipse.osgi.util.NLS;

public class Messages extends NLS {
	private static final String BUNDLE_NAME = Messages.class.getName();


	public static String Completion_method_binding_label;
	public static String Completion_callout_label;
	public static String Completion_callin_label;

	public static String Completion_callout_to_field_label;

	public static String Completion_default_lifting_constructor_label;

	public static String Completion_override_role_label;

	public static String OTLayoutActionGroup_MenuOTPresentations;
	public static String OTLayoutActionGroup_MenuShowCallinLabels;
	public static String OTLayoutActionGroup_MenuDontShowCallinLabels;

	public static String PackageExplorer_DisplayRoleFilesAction;
	public static String PackageExplorer_DisplayRoleFilesDescription;
	public static String PackageExplorer_DisplayRoleFilesTooltip;

	public static String QuickOutline__and_role_files;

	public static String ViewAdaptor_guard_predicate_postfix;

	public static String NewOTProjectWizardPageOne_JREGroup_title;
	public static String NewOTProjectWizardPageOne_Weaving_label;


	public static String Validation_Target18IncompatibleWithOTRE_warning;
	public static String Validation_MultipleComplianceProblems_error;


	static {
		// initialize resource bundle
		NLS.initializeMessages(BUNDLE_NAME, Messages.class);
	}

	private Messages() { /* do not instantiate */ }
}
